package com.logicbig.example;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.ThemeResolver;
import org.springframework.web.servlet.support.RequestContextUtils;
import javax.servlet.http.HttpServletRequest;
import java.util.Map;
import java.util.stream.Collectors;

@Controller
public class ThemeController {

    @RequestMapping("/")
    public String getIndexPage(Model model, ThemeInfo themeInfo, HttpServletRequest request) {
        if (themeInfo.getThemeName() == null) {
            //this is needed for the situation when form first loaded via get method
            //so that the option component can select the last selected theme
            ThemeResolver themeResolver = RequestContextUtils.getThemeResolver(request);
            String themeName = themeResolver.resolveThemeName(request);
            themeInfo = ThemeInfo.getThemeInfoByName(themeName);
        }
        model.addAttribute("themeInfo", themeInfo);
        Map<String, String> themeChoices = ThemeInfo.getAllThemes()
                                                    .stream()
                                                    .collect(Collectors.toMap(
                                                            info -> info.getThemeName(),
                                                            info -> info.getDisplayName())
                                                    );
        //map's key/value equivalent to
        // html's <option value='key'>value</option>
        // used for theme selection
        model.addAttribute("themeChoices", themeChoices);
        return "index";
    }

    @RequestMapping("/otherView")
    public String getPage2() {
        return "other-page";
    }
}